/*
 Example using the SparkFun HX711 breakout board with a scale
 By: Nathan Seidle
 SparkFun Electronics
 Date: November 19th, 2014
 License: This code is public domain but you buy me a beer if you use this and we meet someday (Beerware license).
 
 This is the calibration sketch. Use it to determine the calibration_factor that the main example uses. It also
 outputs the zero_factor useful for projects that have a permanent mass on the scale in between power cycles.
 
 Setup your scale and start the sketch WITHOUT a weight on the scale
 Once readings are displayed place the weight on the scale
 Press +/- or a/z to adjust the calibration_factor until the output readings match the known weight
 Use this calibration_factor on the example sketch
 
 This example assumes pounds (lbs). If you prefer kilograms, change the Serial.print(" lbs"); line to kg. The
 calibration factor will be significantly different but it will be linearly related to lbs (1 lbs = 0.453592 kg).
 
 Your calibration factor may be very positive or very negative. It all depends on the setup of your scale system
 and the direction the sensors deflect from zero state

 This example code uses bogde's excellent library: https://github.com/bogde/HX711
 bogde's library is released under a GNU GENERAL PUBLIC LICENSE

 Arduino pin 2 -> HX711 CLK
 3 -> DOUT
 5V -> VCC
 GND -> GND
 
 Most any pin on the Arduino Uno will be compatible with DOUT/CLK.
 
 The HX711 board can be powered from 2.7V to 5V so the Arduino 5V power should be fine.
 
*/

#include "HX711.h" //This library can be obtained here http://librarymanager/All#Avia_HX711
#include <LiquidCrystal.h>

#define CLK1          14
#define DOUT1       15
#define CLK2          16
#define DOUT2       17
#define Tare_Pin     10

HX711 scale1;
HX711 scale2;
LiquidCrystal lcd(8, 9, 4, 5, 6, 7);        // RS, E, D4, D5, D6, D7

float calibration_factor1 = -21650;         // worked for my scale setup
float calibration_factor2 = -21200; 

void setup() {
  Serial.begin(9600);
  
  lcd.begin(20,4);
     
  Serial.println("HX711 calibration sketch");
  Serial.println("Remove all weight from scale");
  Serial.println("Record Zero factors");
  Serial.println("After readings begin, place known weight on scales");
  Serial.println("Press + or -  to change calibration factor for scale 1");
  Serial.println("Press a or z to change calibration factor for scale 2");
  Serial.println("do this untill weight reads correctly for both scales");
  Serial.println("Then record calibration factors");
  
  
 lcd.clear();
 
  scale1.begin(DOUT1, CLK1);
  scale1.set_scale();
  scale1.tare();	//Reset the scale to 0

  long zero_factor1 = scale1.read_average(); //Get a baseline reading
  Serial.print("Zero factor 1: "); //This can be used to remove the need to tare the scale. Useful in permanent scale projects.
  Serial.println(zero_factor1);
   
  scale2.begin(DOUT2, CLK2);
  scale2.set_scale();
  scale2.tare();    //Reset the scale to 0

  long zero_factor2 = scale2.read_average(); //Get a baseline reading
  Serial.print("Zero factor 2: "); //This can be used to remove the need to tare the scale. Useful in permanent scale projects.
  Serial.println(zero_factor2);
    
}

void loop() {

  scale1.set_scale(calibration_factor1); //Adjust to this calibration factor
  scale2.set_scale(calibration_factor2); //Adjust to this calibration factor
  Serial.print("Reading 1: "); Serial.print(scale1.get_units(), 2);
  Serial.print(" kg");
  Serial.print(" calibration_factor 1: "); Serial.print(calibration_factor1, 2);
  Serial.println();
   
  Serial.print("Reading 2: "); Serial.print(scale2.get_units(), 2);
  Serial.print(" kg"); //Change this to kg and re-adjust the calibration factor if you follow SI units like a sane person
  Serial.print(" calibration_factor 2: "); Serial.print(calibration_factor2, 2);
  Serial.println();
  Serial.println();
  delay(500);
  
  if(Serial.available()) {
    char temp = Serial.read();
    if (temp == '+') calibration_factor1 += 10;
    else if (temp == '-') calibration_factor1 -= 10;
   
    else if (temp == 'a') calibration_factor2 += 10;
    else if (temp == 'z') calibration_factor2 -= 10;
  }
}
